args "--conf-parser --no-handle-version --no-handle-help"

purpose "An alarm clock and volume-fader for OSS and ALSA"

include(header.m4)
define(CURRENT_PROGRAM,para_fade)
define(DEFAULT_CONFIG_FILE,~/.paraslash/fade.conf)
<qu>
section "General options"
#########################

</qu>
include(config_file.m4)
include(loglevel.m4)
<qu>
option "mode" o
#~~~~~~~~~~~~~~
"how to fade volume"
	enum typestr = "mode"
	values = "sleep", "snooze", "fade"
	default = "sleep"
	optional
	details="
		para_fade knows three different fading modes:

		sleep mode: Change to the initial volume and select
		the initial afs mood/playlist. Then fade out until
		the fade-out volume is reached. Switch to the
		sleep mood/playlist until wake time minus fade-in
		time. Finally switch to the wake mood/playlist and
		fade to the fade-in volume.

		fade: Fade the volume to the given value in the
		given time.

		snooze: Fade out, sleep a bit and fade in.
"

option "mixer-api" a
#~~~~~~~~~~~~~~~~~~~
"choose the mixer API"
	string typestr = "api"
	optional
	details = "
		ALSA is preferred over OSS if both APIs are supported
		and this option is not given. To see the supported
		mixer APIs, use this option with an invalid string
		as the mixer API, e.g. --mixer-api help.
	"

option "mixer-device" m
#~~~~~~~~~~~~~~~~~~~~~~
"choose mixer device"
	string typestr = "device"
	optional
	details = "
		The default device (used if this option is not given)
		depends on the selected mixer API. For ALSA, the
		default is 'hw:0' which corresponds to the first sound
		device. For OSS, '/dev/mixer' is used as the default.
	"

option "mixer-channel" C
#~~~~~~~~~~~~~~~~~~~~~~~
"select the analog mixer channel"
	string typestr = "channel"
	optional
	details = "
		For the ALSA mixer API, the possible values are
		determined at runtime depending on the hardware and
		can be printed by specifying an invalid mixer channel,
		for example --mixer-channel help. The default channel
		is 'Master'.

		For OSS the possible values are invariably 'volume',
		'bass', 'treble', 'synth', 'pcm', 'speaker', 'line',
		'mic', 'cd', 'imix', 'altpcm', 'reclev', 'igain',
		'ogain'. However, not all listed channels might be
		supported on any particular hardware. The default
		channel is 'volume'.
	"

section "Options for sleep mode"
################################

option "ivol" -
#~~~~~~~~~~~~~~
"set initial volume"
	int typestr = "volume"
	default = "60"
	optional
	details = "
		Used as the start volume, before fading out to the
		fade out volume.
	"

option "fo-mood" -
#~~~~~~~~~~~~~~~~~
"afs mood/playlist during fade out"
	string typestr = "mood_spec"
	default = "m/fade"
	optional
	details = "
		Select this mood right after setting the
		volume. Example: --fo-mood m/sleep
"

option "fo-time" -
#~~~~~~~~~~~~~~~~~
"fall asleep fade out time"
	int typestr = "seconds"
	default = "1800"
	optional
	details = "
		No fading if set to 0.
	"

option "fo-vol" -
#~~~~~~~~~~~~~~~~
"volume to fade out to"
	int typestr = "volume"
	default = "20"
	optional

option "sleep-mood" -
#~~~~~~~~~~~~~~~~~~~~
"sleep time afs mood/playlist"
	string typestr = "mood_spec"
	default = "m/sleep"
	optional
	details = "
		Select the given afs mood/playlist after the fade
		out is complete. If unset, the \"stop\" command is
		sent to para_server.
	"

option "wake-hour" H
#~~~~~~~~~~~~~~~~~~~
"(0-23) (default: now + 9 hours)"
	int typestr = "hour"
	optional

option "wake-min" M
#~~~~~~~~~~~~~~~~~~
"(0-59)"
	int typestr = "minutes"
	default = "0"
	optional

option "fi-mood" -
#~~~~~~~~~~~~~~~~~
"afs mood/playlist during fade in"
	string typestr = "mood_spec"
	default = "m/wake"
	optional
	details = "
		Change to this afs mood/playlist on wake time.
	"

option "fi-time" -
#~~~~~~~~~~~~~~~~~
"wake up fade in time"
	int typestr="seconds"
	default="1200"
	optional
 	details = "
		No fading in if set to 0.
	"

option "fi-vol" -
#~~~~~~~~~~~~~~~~
"volume to fade to at wake time"
	int typestr = "volume"
	default = "80"
	optional

section "Options for snooze mode"
#################################

option "so-time" -
#~~~~~~~~~~~~~~~~~
"snooze-out time"
	int typestr = "seconds"
	default = "30"
	optional

option "so-vol" -
#~~~~~~~~~~~~~~~~
"volume to fade to before snooze"
	int typestr = "volume"
	default = "20"
	optional

option "snooze-time" -
#~~~~~~~~~~~~~~~~~~~~~
"delay"
	int typestr = "seconds"
	default = "600"
	optional

option "si-time" -
#~~~~~~~~~~~~~~~~~
"snooze-in time"
	int typestr = "seconds"
	default = "180"
	optional

option "si-vol" -
#~~~~~~~~~~~~~~~~
"volume to fade to after snooze"
	int typestr = "volume"
	default = "80"
	optional

section "Options for fade mode"
###############################

option "fade-vol" f
#~~~~~~~~~~~~~~~~~~
"volume to fade to"
	int typestr = "volume"
	default = "50"
	optional

option "fade-time" t
#~~~~~~~~~~~~~~~~~~~
"fading time"
	int typestr = "seconds"
	default = "5"
	optional
</qu>
